- :class:`linear_model.LogisticRegressionCV` now correctly handles the case when the
  `scoring` parameter is set (to something not `None`) and when the CV splits result in
  folds where some class labels are missing.
  By :user:`Christian Lorentzen <lorentzenchr>`.
